### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Interfaces for the Zope 3 based product package

$Id: interfaces.py 51555 2008-08-30 22:59:06Z cray $
"""
__author__  = "Elena Antusheva, 2008"
__license__ = "GPL"
__version__ = "$Revision: 51555 $"
 
from zope.interface import Interface

from zope.schema import Text, TextLine, Field, Bool, Datetime, URI, Tuple, Float
from zope.app.container.interfaces import IContained, IContainer
from zope.app.container.constraints import ItemTypePrecondition
from zope.app.container.constraints import ContainerTypesConstraint
from zope.schema import Object
                

class IAuthor (Interface) :
      
      author_name = TextLine(
                       title = u'author_name',
                       description = u'author_name',
                       default = u'',
                       required = False)

      author_email = TextLine(
                       title = u'author_email',
                       description = u'author_email',
                       default = u'',
                       required = False)

class IRSSAdd(Interface) :
      title = TextLine(
        title = u'Title',
        description = u'Title',
        default = u'',
        required = False)

      subtitle = TextLine(
        title = u'Subtitle',
        description = u'Subtitle',
        default = u'',
        required = False)

      link = URI(
        title = u'URL',
        description = u'URL',
        required = True)

      author = Tuple(title=u'authors',
                    description=u'Some authors',
                    required=False,
                    value_type=Object(title=(u'author'),
                                      description=(u'...'),
                                      schema=IAuthor,
                                     )
                   )
                   

                                                                
      id = TextLine(
        title = u"id",
        description = u"id",
        )

class IRSS(IRSSAdd) :
      """ """
      updated = TextLine(
        title = u"Updated",
        description = u"Last modification time ",
        readonly = True,)

class IRSSEntry (Interface) :
      ### TODO: ЭТо видимо относится к интерфейсу ентри в ленте. Давай
      ### заведем отдельный интерфейс IRSSEnter и свалим их все туда и пока
      ### забудем про них - добъемя вначеале пустых лент

      entry_title = TextLine(
                       title = u'entry_title',
                       description = u'entry_title',
                       default = u'',
                       required = False)

      entry_link = URI(
        title = u'URL',
        description = u'URL',
        required = True)

      entry_id = TextLine(
        title = u"entry_id",
        description = u"entry_id",
        )

      entry_updated = Datetime(
        title = u"Date of updated",
        description = u"Date of updated")

      entry_summary  = TextLine(
                       title = u'entry_summary',
                       description = u'entry_summary',
                       default = u'',
                       required = False)


### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Product class for the Zope 3 based product package

$Id: rssadappter.py 49482 2008-01-15 19:24:29Z cray $
"""
__author__  = "Elena Antusheva, 2008"
__license__ = "GPL"
__version__ = "$Revision: 49482 $"

from zope.app.zapi import getUtility
from ng.app.objectqueue.interfaces import IObjectQueue
from zope.component import ComponentLookupError
from interfaces import IRSS

def RSSAdapter(context) :
    """ """
    try :
        return getUtility(IRSS, context=context)
    except ComponentLookupError :
        print "\nCannot get utility with IRSS interface\n"



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Product class for the Zope 3 based product package

$Id: rssadappter.py 49482 2008-01-15 19:24:29Z cray $
"""
__author__  = "Elena Antusheva, 2008"
__license__ = "GPL"
__version__ = "$Revision: 49482 $"

from zope.app.zapi import getUtility
from zope.component import ComponentLookupError
from zope.dublincore.interfaces import IZopeDublinCore
from zope.traversing.browser import absoluteURL

class ZDC2RSSAdapter(object) :
    """ """
    def __init__(self,context,request) :
        dc = IZopeDublinCore(context)
        self.title = dc.title
        self.updated = dc.modified
        self.summary = dc.description
        self.id = dc.Identifier
        self.link = absoluteURL(context,request)

        




### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Product class for the Zope 3 based product package

$Id: rss.py 51555 2008-08-30 22:59:06Z cray $
"""
__author__  = "Elena Antusheva, 2008"
__license__ = "GPL"
__version__ = "$Revision: 51555 $"

from zope.interface import Interface
from zope.interface import implements,implementedBy
from interfaces import IRSS,IAuthor
from persistent import Persistent
from zope.app.form import CustomWidgetFactory
from zope.app.form.browser import ObjectWidget
from zope.app.form.browser import TupleSequenceWidget
from ng.adapter.mtime.interfaces import IMTime

# TODO: От перзистент должен пораждатся. И хорошо бы в класс вписать
# умолчания всех переменных реализуюемого им интерфейса
                
class RSS( Persistent ) :

    implements(IRSS)

    def __init__(self,*kv,**kw) :
        super(RSS,self).__init__(*kv,**kw)
        self.author = ()


    title = u""

    subtitle = u""

    link = u""

    author = None

    id = u""

    @property
    def updated(self) :
        return IMTime(self).strftime("%Y-%m-%dT%H:%M:%SZ")

class Author( Persistent ) :

    implements(IAuthor)

    author_name = u""

    author_email = u""

AuthorTupleWidget = CustomWidgetFactory(
       TupleSequenceWidget,
       subwidget=CustomWidgetFactory(
       ObjectWidget,
       Author))



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Product class for the Zope 3 based product package

$Id: rssview.py 51555 2008-08-30 22:59:06Z cray $
"""
__author__  = ""
__license__ = "GPL"
__version__ = "$Revision: 51555 $"

from zope.interface import Interface
from zope.interface import implements,implementedBy
from ng.app.objectqueue.interfaces import IObjectQueueAll
from ng.app.rss.interfaces import IRSS,IRSSEntry
from zope.app import zapi
from zope.component import queryMultiAdapter

class RSSView(object) :
    
    # Тута адаптируем контекст к IObjectQueue
    # Тута к rss
    # Атрибутики rss проксируем на адаптированный RSS
    # Рисуем один атрибутик который возвращает entries, хавая содержимое из IObjectQueue.values()
    # и приводя его к IRSSEntry. Адаптера пока нет и не нужно пока
    # А потом пишем pt-файл

    """ RSSView
    """    
    
    @property
    def entries(self):
        """ Рисуем один атрибутик который возвращает entries, хавая содержимое из IObjectQueue.values()
        """
        queue = IObjectQueueAll(self.context).next()
        return ( x for x in (
            queryMultiAdapter((y,self.request),IRSSEntry,default=None)
            for y in queue.values()) if x is not None)

    @property
    def rss(self):
        return IRSS(self.context)
